/*
 * Segment 8 Parametrierung und Konfiguration, SWE 8.2 Parametrierung - Bibliothek
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */
package de.bsvrz.puk.param.lib;

import java.io.Serializable;

import de.bsvrz.puk.param.lib.ParameterInfo.SerializableParameterInfo;

/**
 * Serialisierbares Objekt, das ab Version 1.3.4 der Bibliothek an die
 * Parametrierung versendet wird und zusätzliche Abfrageparameter für die
 * Anfrage enthält. Als Parametrierungsapplikation ist mindestens Version 1.7.7
 * erforderlich.
 *
 * @author BitCtrl Systems GmbH, Uwe Peuker
 */
public class ParameterAbfrageObjekt implements Serializable {

	/** Versions-ID für die Serialisierung. */
	private static final long serialVersionUID = 1L;

	/** die Liste der Parameterinfos, für die eine Abfrage erfolgen soll. */
	private final SerializableParameterInfo[] parameterInfos;

	/** die Markierung, ob Daten mit der Antwort erwartet werden oder nicht. */
	private final boolean datenLiefern;

	/**
	 * Konstruktor, erzeugt ein neues Abfrageobjekt.
	 *
	 * @param info
	 *            die Parameterbeschreibungen, die abgefragt werden sollen
	 * @param datenLiefern
	 *            Daten mit abfragen ?
	 */
	public ParameterAbfrageObjekt(final SerializableParameterInfo[] info,
			final boolean datenLiefern) {
		parameterInfos = info;
		this.datenLiefern = datenLiefern;
	}

	/**
	 * liefert die abfragenen Parameterdefinitionen.
	 *
	 * @return die Definitionen
	 */
	public SerializableParameterInfo[] getParameterInfos() {
		return parameterInfos;
	}

	/**
	 * ermittelt, ob Daten in der Antwort geliefert werden sollen oder nicht.
	 *
	 * @return den Zustand
	 */
	public boolean isDatenLiefern() {
		return datenLiefern;
	}
}
